#include <avformat.h>

#include "input.h"

static void print_ts(uint64_t v)
{
  if (v == AV_NOPTS_VALUE) {
    printf("%16s", "---");
  } else {
    printf("%16"PRId64"", v);
  }
}

static void pkt_print(AVPacket *pkt)
{
  printf("%10d\t", pkt->size);
  print_ts(pkt->pts);
  printf("\t");
  print_ts(pkt->dts);
  if (pkt->flags & PKT_FLAG_KEY) {
    printf("\tKey Frame");
  }
  printf("\n");
}

static void header_print(void)
{
  printf("%10s", "# Size (bytes)\t");
  printf("%16s", " Presentation TS\t");
  printf("%16s", "     Decoding TS\n");
}

int main(int argc, char *argv[])
{
  AVFormatContext *s;
  int done;

  avcodec_register_all();
  av_register_all();

  s = open_input_stream(argv[1]);
  if (s == NULL) {
    fprintf(stderr, "Cannot open input file %s\n", argv[1]);

    return -1;
  }

  header_print();
  done = 0;
  while (!done) {
    AVPacket *pkt;

    pkt = read_input_packet(s);
    if (pkt == NULL) {
      done = 1;
    } else {
      if (s->streams[pkt->stream_index]->codec->codec_type == CODEC_TYPE_VIDEO) {
        pkt_print(pkt);
      }
      av_free_packet(pkt);
    }
  }

  return 0;
}
